@@ -12,7 +12,7 @@ from datetime import datetime, timedelta
 from hashlib import md5
 
 from thrift.transport.TSocket import TSocket
-from thrift.transport.TTransport import TBufferedTransport
+from thrift.transport.TTransport import TBufferedTransport, TTransportException
 from thrift.protocol import TBinaryProtocol
 from hbase import Hbase
 from hbase.ttypes import Mutation
@@ -23,15 +23,21 @@ class Storage(BaseStorage):
     crypto_col = 'crypto'
     detector_col = 'detector'
     image_col = 'raw'
+    storage = None
 
     def __init__(self,context):
         self.context=context
         self.table = self.context.config.HBASE_STORAGE_TABLE
         self.data_fam = self.context.config.HBASE_STORAGE_FAMILY
+        try:
+            self.connect()
+        except TTransportException:
+            None
+
+    def connect(self):
         transport = TBufferedTransport(TSocket(host=self.context.config.HBASE_STORAGE_SERVER_HOST, port=self.context.config.HBASE_STORAGE_SERVER_PORT))
         transport.open()
         protocol = TBinaryProtocol.TBinaryProtocol(transport)
-
         self.storage = Hbase.Client(protocol)
 
     def put(self, path, bytes):
@@ -41,7 +47,10 @@ class Storage(BaseStorage):
             key = md5(path.encode('utf-8')).hexdigest() + '-' + path.encode('utf-8')
         
         r = [Mutation(column=self.data_fam + ':' + self.image_col, value=bytes)]
+        if self.storage is None:
+            self.connect()
         self.storage.mutateRow(self.table, key, r)
+
         return path
 
     def put_crypto(self, path):
@@ -57,6 +66,9 @@ class Storage(BaseStorage):
             key = md5(path.encode('utf-8')).hexdigest() + '-' + path.encode('utf-8')
 
         r = [Mutation(column=self.data_fam + ':' + self.crypto_col, value=self.context.config.SECURITY_KEY)]
+
+        if self.storage is None:
+            self.connect()
         self.storage.mutateRow(self.table, key, r)
  
     def put_detector_data(self, path, data):
@@ -66,6 +78,8 @@ class Storage(BaseStorage):
             key = md5(path.encode('utf-8')).hexdigest() + '-' + path.encode('utf-8')
 
         r = [Mutation(column=self.data_fam + ':' + self.detector_col, value=dumps(data))]
+        if self.storage is None:
+            self.connect()
         self.storage.mutateRow(self.table, key, r)
 
     def get_crypto(self, path):
@@ -77,6 +91,8 @@ class Storage(BaseStorage):
         except UnicodeEncodeError:
             key = md5(path.encode('utf-8')).hexdigest() + '-' + path.encode('utf-8')
 
+        if self.storage is None:
+            self.connect()
         crypto = self.storage.get(self.table, key, self.data_fam + ':' + self.crypto_col)
 
         if not crypto:
@@ -89,6 +105,8 @@ class Storage(BaseStorage):
         except UnicodeEncodeError:
             key = md5(path.encode('utf-8')).hexdigest() + '-' + path.encode('utf-8')
 
+        if self.storage is None:
+            self.connect()
         data = self.storage.get(self.table, key, self.data_fam + ':' + self.detector_col)
 
         try:
@@ -102,7 +120,10 @@ class Storage(BaseStorage):
         except UnicodeEncodeError:
             key = md5(path.encode('utf-8')).hexdigest() + '-' + path.encode('utf-8')
 
+        if self.storage is None:
+            self.connect()
         r = self.storage.get(self.table, key, self.data_fam + ':' + self.image_col)
+
         try:
             return r[0].value
         except IndexError: 
@@ -114,6 +135,8 @@ class Storage(BaseStorage):
         except UnicodeEncodeError:
             key = md5(path.encode('utf-8')).hexdigest() + '-' + path.encode('utf-8')
 
+        if self.storage is None:
+            self.connect()
         r = self.storage.get(self.table, key, self.data_fam + ':' + self.image_col)
 
         return len(r) != 0
@@ -125,6 +148,9 @@ class Storage(BaseStorage):
             key = md5(path.encode('utf-8')).hexdigest() + '-' + path.encode('utf-8')
 
         r = [Mutation(column=self.data_fam + ':' + self.image_col, isDelete=True)]
+
+        if self.storage is None:
+            self.connect()
         self.storage.mutateRow(self.table, key, r)
 
     def resolve_original_photo_path(self,filename):
